pub enum PatternN {
Comp(Vec<PatternN>, PatternType),
Tensor(Vec<PatternN>),
Ket(KetState),
Unitary(Box<AtomN>),
}Expand description
A normal-form patterns
Variants
Comp(Vec<PatternN>, PatternType)
A composition “p_1 . … . p_n” with given type
Tensor(Vec<PatternN>)
A tensor “p_1 x … x p_n”
Ket(KetState)
A single ket state “|x>”
Unitary(Box<AtomN>)
An “atomic” term. Compound terms are evaluated to pattern compositions/tensors.
Implementations
Sourceimpl PatternN
impl PatternN
Sourcepub fn to_inj_and_proj(&self) -> (Mat<Complex<f64>>, Mat<Complex<f64>>)
pub fn to_inj_and_proj(&self) -> (Mat<Complex<f64>>, Mat<Complex<f64>>)
Convert a normal-form pattern of type qm < qn to an m x n isometry matrix i
and an n x n projector p such that
p + ii^dagger = id